##  Overview
Automations are a no-code feature that enables you to establish workflows triggered by specific events on fact sheets. As an admin user, you can configure automations to eliminate manual tasks, enrich user engagement, facilitate collaboration, and ensure data quality within your workspace.
Only admin users can manage automations. To view and configure automations, in the administration area, navigate to Automations.
The following image shows the overall logic of automations.
![Configuration of Automations: Events, Conditions, and Actions](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2747e17e7a4410149fa4dee156c90cb6_LowRes.png)
Configuration of Automations: Events, Conditions, and Actions
